@@ -4,31 +4,31 @@ from .. import IntegrationTest
 
 class TestFront(IntegrationTest):
     def test_best(self):
-        with self.recorder.use_cassette('TestFront.test_best'):
+        with self.use_cassette():
             submissions = list(self.reddit.front.best())
         assert len(submissions) == 100
 
     def test_controversial(self):
-        with self.recorder.use_cassette('TestFront.test_controversial'):
+        with self.use_cassette():
             submissions = list(self.reddit.front.controversial())
         assert len(submissions) == 100
 
     def test_gilded(self):
-        with self.recorder.use_cassette('TestFront.test_gilded'):
+        with self.use_cassette():
             submissions = list(self.reddit.front.gilded())
         assert len(submissions) == 100
 
     def test_hot(self):
-        with self.recorder.use_cassette('TestFront.test_hot'):
+        with self.use_cassette():
             submissions = list(self.reddit.front.hot())
         assert len(submissions) == 100
 
     def test_new(self):
-        with self.recorder.use_cassette('TestFront.test_new'):
+        with self.use_cassette():
             submissions = list(self.reddit.front.new())
         assert len(submissions) == 100
 
     def test_top(self):
-        with self.recorder.use_cassette('TestFront.test_top'):
+        with self.use_cassette():
             submissions = list(self.reddit.front.top())
         assert len(submissions) == 100
